import React, { useCallback, useEffect, useRef, useState } from "react";
import dayjs from "dayjs";
import { Link } from "react-router-dom";

import {
  ArrowImg,
  IconButton,
  InputElement,
  InputLabel,
  InputWrapper,
  StartWrapper,
  LessonItem,
  Lessonname,
} from "./style";

import arrow from "../assets/36-arrow-right.svg";
import { connect, getSocket } from "../socket";
import { getConfigValue } from "@ijl/cli";
import { keycloak } from "../__data__/const";

export const Journal = () => {
  const [lessons, setLessons] = useState(null);

  useEffect(() => {
    connect();
    const socket = getSocket();
    socket.on("lessons", (data) => {
      setLessons(data);
    });

    const check = async () => {
      if (keycloak.authenticated) {
        keycloak;
        const rq = await fetch(`${getConfigValue("journal.back.url")}/check`, {
          headers: {
            accept: "application/json",
            authorization: `Bearer ${keycloak.token}`,
          },
        });
        const data = await rq.json();

        console.log("check", data);
      } else {
        keycloak.onAuthSuccess = check
      }
    };

    check();
  }, []);

  const [answer, setAnswer] = useState(null);

  const send = async () => {
    if (keycloak.authenticated) {
      keycloak;
      const rq = await fetch(`${getConfigValue("journal.back.url")}/test`, {
        headers: {
          accept: "application/json",
          authorization: `Bearer ${keycloak.token}`,
        },
      });
      const data = await rq.json();
      setAnswer(data);
    } else {
      setAnswer({ message: 'Пользователь не авторизован' })
    }
  }

  const [value, setValue] = useState("");
  const handleChange = useCallback(
    (event) => {
      setValue(event.target.value.toUpperCase());
    },
    [setValue]
  );
  const inputRef = useRef<HTMLInputElement>(null);

  const handleSubmit = useCallback(
    (event) => {
      event.preventDefault();

      const socket = getSocket();
      socket.emit("create-lesson", { lessonName: value });
      setValue("");
    },
    [value]
  );

  return (
    <StartWrapper>
      <IconButton onClick={send} title="Запрос">
        <ArrowImg src={arrow} />
      </IconButton>
      <pre>{JSON.stringify(answer, null, 4)}</pre>
      <form onSubmit={handleSubmit}>
        <InputWrapper>
          <InputLabel htmlFor="input">Название новой лекции:</InputLabel>
          <InputElement
            value={value}
            onChange={handleChange}
            ref={inputRef}
            id="input"
            type="text"
            autoComplete="off"
          />
          <IconButton type="submit">
            <ArrowImg src={arrow} />
          </IconButton>
        </InputWrapper>
      </form>
      <ul style={{ paddingLeft: 0 }}>
        {lessons?.map((lesson) => (
          <LessonItem key={lesson.id}>
            <Link to={`/journal/l/${lesson.id}`} style={{ display: "flex" }}>
              <Lessonname>{lesson.name}</Lessonname>
              <span>{dayjs(lesson.ts).format("DD MMMM YYYYг.")}</span>
              <span style={{ marginLeft: "auto" }}>
                Участников - {lesson.padavans.length}
              </span>
            </Link>
          </LessonItem>
        ))}
      </ul>
    </StartWrapper>
  );
};
